pub struct AndroidBuildProto {Show 14 fields
pub id: Option<String>,
pub product: Option<String>,
pub carrier: Option<String>,
pub radio: Option<String>,
pub bootloader: Option<String>,
pub client: Option<String>,
pub timestamp: Option<i64>,
pub google_services: Option<i32>,
pub device: Option<String>,
pub sdk_version: Option<i32>,
pub model: Option<String>,
pub manufacturer: Option<String>,
pub build_product: Option<String>,
pub ota_installed: Option<bool>,
}Fields
id: Option<String>product: Option<String>carrier: Option<String>radio: Option<String>bootloader: Option<String>client: Option<String>timestamp: Option<i64>google_services: Option<i32>device: Option<String>sdk_version: Option<i32>model: Option<String>manufacturer: Option<String>build_product: Option<String>ota_installed: Option<bool>Implementations
Sourceimpl AndroidBuildProto
impl AndroidBuildProto
Sourcepub fn product(&self) -> &str
pub fn product(&self) -> &str
Returns the value of product, or the default value if product is unset.
Sourcepub fn carrier(&self) -> &str
pub fn carrier(&self) -> &str
Returns the value of carrier, or the default value if carrier is unset.
Sourcepub fn radio(&self) -> &str
pub fn radio(&self) -> &str
Returns the value of radio, or the default value if radio is unset.
Sourcepub fn bootloader(&self) -> &str
pub fn bootloader(&self) -> &str
Returns the value of bootloader, or the default value if bootloader is unset.
Sourcepub fn client(&self) -> &str
pub fn client(&self) -> &str
Returns the value of client, or the default value if client is unset.
Sourcepub fn timestamp(&self) -> i64
pub fn timestamp(&self) -> i64
Returns the value of timestamp, or the default value if timestamp is unset.
Sourcepub fn google_services(&self) -> i32
pub fn google_services(&self) -> i32
Returns the value of google_services, or the default value if google_services is unset.
Sourcepub fn device(&self) -> &str
pub fn device(&self) -> &str
Returns the value of device, or the default value if device is unset.
Sourcepub fn sdk_version(&self) -> i32
pub fn sdk_version(&self) -> i32
Returns the value of sdk_version, or the default value if sdk_version is unset.
Sourcepub fn model(&self) -> &str
pub fn model(&self) -> &str
Returns the value of model, or the default value if model is unset.
Sourcepub fn manufacturer(&self) -> &str
pub fn manufacturer(&self) -> &str
Returns the value of manufacturer, or the default value if manufacturer is unset.
Sourcepub fn build_product(&self) -> &str
pub fn build_product(&self) -> &str
Returns the value of build_product, or the default value if build_product is unset.
Sourcepub fn ota_installed(&self) -> bool
pub fn ota_installed(&self) -> bool
Returns the value of ota_installed, or the default value if ota_installed is unset.