pub struct Availability {
pub restriction: Option<i32>,
pub offer_type: Option<i32>,
pub rule: Option<Rule>,
pub perdeviceavailabilityrestriction: Vec<PerDeviceAvailabilityRestriction>,
pub available_if_owned: Option<bool>,
pub install: Vec<Install>,
pub filter_info: Option<FilterEvaluationInfo>,
pub ownership_info: Option<OwnershipInfo>,
pub availability_problem: Vec<AvailabilityProblem>,
pub hidden: Option<bool>,
}Fields
restriction: Option<i32>offer_type: Option<i32>rule: Option<Rule>perdeviceavailabilityrestriction: Vec<PerDeviceAvailabilityRestriction>available_if_owned: Option<bool>install: Vec<Install>filter_info: Option<FilterEvaluationInfo>ownership_info: Option<OwnershipInfo>availability_problem: Vec<AvailabilityProblem>Implementations
Sourceimpl Availability
impl Availability
Sourcepub fn restriction(&self) -> i32
pub fn restriction(&self) -> i32
Returns the value of restriction, or the default value if restriction is unset.
Sourcepub fn offer_type(&self) -> i32
pub fn offer_type(&self) -> i32
Returns the value of offer_type, or the default value if offer_type is unset.
Sourcepub fn available_if_owned(&self) -> bool
pub fn available_if_owned(&self) -> bool
Returns the value of available_if_owned, or the default value if available_if_owned is unset.
Returns the value of hidden, or the default value if hidden is unset.