pub struct Bucket {
pub multi_corpus: Option<bool>,
pub title: Option<String>,
pub icon_url: Option<String>,
pub full_contents_url: Option<String>,
pub relevance: Option<f64>,
pub estimated_results: Option<i64>,
pub analytics_cookie: Option<String>,
pub full_contents_list_url: Option<String>,
pub next_page_url: Option<String>,
pub ordered: Option<bool>,
}Fields
multi_corpus: Option<bool>title: Option<String>icon_url: Option<String>full_contents_url: Option<String>relevance: Option<f64>estimated_results: Option<i64>full_contents_list_url: Option<String>next_page_url: Option<String>ordered: Option<bool>Implementations
Sourceimpl Bucket
impl Bucket
Sourcepub fn multi_corpus(&self) -> bool
pub fn multi_corpus(&self) -> bool
Returns the value of multi_corpus, or the default value if multi_corpus is unset.
Sourcepub fn title(&self) -> &str
pub fn title(&self) -> &str
Returns the value of title, or the default value if title is unset.
Sourcepub fn icon_url(&self) -> &str
pub fn icon_url(&self) -> &str
Returns the value of icon_url, or the default value if icon_url is unset.
Sourcepub fn full_contents_url(&self) -> &str
pub fn full_contents_url(&self) -> &str
Returns the value of full_contents_url, or the default value if full_contents_url is unset.
Sourcepub fn relevance(&self) -> f64
pub fn relevance(&self) -> f64
Returns the value of relevance, or the default value if relevance is unset.
Sourcepub fn estimated_results(&self) -> i64
pub fn estimated_results(&self) -> i64
Returns the value of estimated_results, or the default value if estimated_results is unset.
Returns the value of analytics_cookie, or the default value if analytics_cookie is unset.
Sourcepub fn full_contents_list_url(&self) -> &str
pub fn full_contents_list_url(&self) -> &str
Returns the value of full_contents_list_url, or the default value if full_contents_list_url is unset.
Sourcepub fn next_page_url(&self) -> &str
pub fn next_page_url(&self) -> &str
Returns the value of next_page_url, or the default value if next_page_url is unset.