pub struct ClientDownloadRequest {Show 14 fields
pub url: Option<String>,
pub digests: Option<Digests>,
pub length: Option<i64>,
pub resources: Vec<Resource>,
pub signature: Option<SignatureInfo>,
pub user_initiated: Option<bool>,
pub client_asn: Vec<String>,
pub file_basename: Option<String>,
pub download_type: Option<i32>,
pub locale: Option<String>,
pub apk_info: Option<ApkInfo>,
pub android_id: Option<u64>,
pub originating_packages: Vec<String>,
pub originating_signature: Option<SignatureInfo>,
}Fields
url: Option<String>digests: Option<Digests>length: Option<i64>resources: Vec<Resource>signature: Option<SignatureInfo>user_initiated: Option<bool>client_asn: Vec<String>file_basename: Option<String>download_type: Option<i32>locale: Option<String>apk_info: Option<ApkInfo>android_id: Option<u64>originating_packages: Vec<String>originating_signature: Option<SignatureInfo>Implementations
Sourceimpl ClientDownloadRequest
impl ClientDownloadRequest
Sourcepub fn length(&self) -> i64
pub fn length(&self) -> i64
Returns the value of length, or the default value if length is unset.
Sourcepub fn user_initiated(&self) -> bool
pub fn user_initiated(&self) -> bool
Returns the value of user_initiated, or the default value if user_initiated is unset.
Sourcepub fn file_basename(&self) -> &str
pub fn file_basename(&self) -> &str
Returns the value of file_basename, or the default value if file_basename is unset.
Sourcepub fn download_type(&self) -> i32
pub fn download_type(&self) -> i32
Returns the value of download_type, or the default value if download_type is unset.
Sourcepub fn locale(&self) -> &str
pub fn locale(&self) -> &str
Returns the value of locale, or the default value if locale is unset.
Sourcepub fn android_id(&self) -> u64
pub fn android_id(&self) -> u64
Returns the value of android_id, or the default value if android_id is unset.