pub struct ContainerView {
pub selected: Option<bool>,
pub title: Option<String>,
pub list_url: Option<String>,
pub server_logs_cookie: Option<Vec<u8>>,
}Fields
selected: Option<bool>title: Option<String>list_url: Option<String>Implementations
Sourceimpl ContainerView
impl ContainerView
Sourcepub fn selected(&self) -> bool
pub fn selected(&self) -> bool
Returns the value of selected, or the default value if selected is unset.
Sourcepub fn title(&self) -> &str
pub fn title(&self) -> &str
Returns the value of title, or the default value if title is unset.
Sourcepub fn list_url(&self) -> &str
pub fn list_url(&self) -> &str
Returns the value of list_url, or the default value if list_url is unset.
Returns the value of server_logs_cookie, or the default value if server_logs_cookie is unset.