pub struct ContentRating {
pub title: Option<String>,
pub recommendation_and_description_html: Option<String>,
pub content_rating_image: Option<ContentRatingImage>,
pub recommendation: Option<String>,
pub description: Option<String>,
}Fields
title: Option<String>recommendation_and_description_html: Option<String>content_rating_image: Option<ContentRatingImage>recommendation: Option<String>description: Option<String>Implementations
Sourceimpl ContentRating
impl ContentRating
Sourcepub fn title(&self) -> &str
pub fn title(&self) -> &str
Returns the value of title, or the default value if title is unset.
Sourcepub fn recommendation_and_description_html(&self) -> &str
pub fn recommendation_and_description_html(&self) -> &str
Returns the value of recommendation_and_description_html, or the default value if recommendation_and_description_html is unset.
Sourcepub fn recommendation(&self) -> &str
pub fn recommendation(&self) -> &str
Returns the value of recommendation, or the default value if recommendation is unset.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.