pub struct DeviceConfigurationProto {Show 24 fields
pub touch_screen: Option<i32>,
pub keyboard: Option<i32>,
pub navigation: Option<i32>,
pub screen_layout: Option<i32>,
pub has_hard_keyboard: Option<bool>,
pub has_five_way_navigation: Option<bool>,
pub screen_density: Option<i32>,
pub gl_es_version: Option<i32>,
pub system_shared_library: Vec<String>,
pub system_available_feature: Vec<String>,
pub native_platform: Vec<String>,
pub screen_width: Option<i32>,
pub screen_height: Option<i32>,
pub system_supported_locale: Vec<String>,
pub gl_extension: Vec<String>,
pub device_class: Option<i32>,
pub max_apk_download_size_mb: Option<i32>,
pub smallest_screen_width_dp: Option<i32>,
pub low_ram_device: Option<i32>,
pub total_memory_bytes: Option<i64>,
pub max_num_of_cpu_cores: Option<i32>,
pub device_feature: Vec<DeviceFeature>,
pub unknown28: Option<i32>,
pub unknown30: Option<i32>,
}Fields
touch_screen: Option<i32>keyboard: Option<i32>screen_layout: Option<i32>has_hard_keyboard: Option<bool>screen_density: Option<i32>gl_es_version: Option<i32>system_available_feature: Vec<String>native_platform: Vec<String>screen_width: Option<i32>screen_height: Option<i32>system_supported_locale: Vec<String>gl_extension: Vec<String>device_class: Option<i32>max_apk_download_size_mb: Option<i32>smallest_screen_width_dp: Option<i32>low_ram_device: Option<i32>total_memory_bytes: Option<i64>max_num_of_cpu_cores: Option<i32>device_feature: Vec<DeviceFeature>unknown28: Option<i32>unknown30: Option<i32>Implementations
Sourceimpl DeviceConfigurationProto
impl DeviceConfigurationProto
Sourcepub fn touch_screen(&self) -> i32
pub fn touch_screen(&self) -> i32
Returns the value of touch_screen, or the default value if touch_screen is unset.
Sourcepub fn keyboard(&self) -> i32
pub fn keyboard(&self) -> i32
Returns the value of keyboard, or the default value if keyboard is unset.
Returns the value of navigation, or the default value if navigation is unset.
Sourcepub fn screen_layout(&self) -> i32
pub fn screen_layout(&self) -> i32
Returns the value of screen_layout, or the default value if screen_layout is unset.
Sourcepub fn has_hard_keyboard(&self) -> bool
pub fn has_hard_keyboard(&self) -> bool
Returns the value of has_hard_keyboard, or the default value if has_hard_keyboard is unset.
Returns the value of has_five_way_navigation, or the default value if has_five_way_navigation is unset.
Sourcepub fn screen_density(&self) -> i32
pub fn screen_density(&self) -> i32
Returns the value of screen_density, or the default value if screen_density is unset.
Sourcepub fn gl_es_version(&self) -> i32
pub fn gl_es_version(&self) -> i32
Returns the value of gl_es_version, or the default value if gl_es_version is unset.
Sourcepub fn screen_width(&self) -> i32
pub fn screen_width(&self) -> i32
Returns the value of screen_width, or the default value if screen_width is unset.
Sourcepub fn screen_height(&self) -> i32
pub fn screen_height(&self) -> i32
Returns the value of screen_height, or the default value if screen_height is unset.
Sourcepub fn device_class(&self) -> i32
pub fn device_class(&self) -> i32
Returns the value of device_class, or the default value if device_class is unset.
Sourcepub fn max_apk_download_size_mb(&self) -> i32
pub fn max_apk_download_size_mb(&self) -> i32
Returns the value of max_apk_download_size_mb, or the default value if max_apk_download_size_mb is unset.
Sourcepub fn smallest_screen_width_dp(&self) -> i32
pub fn smallest_screen_width_dp(&self) -> i32
Returns the value of smallest_screen_width_dp, or the default value if smallest_screen_width_dp is unset.
Sourcepub fn low_ram_device(&self) -> i32
pub fn low_ram_device(&self) -> i32
Returns the value of low_ram_device, or the default value if low_ram_device is unset.
Sourcepub fn total_memory_bytes(&self) -> i64
pub fn total_memory_bytes(&self) -> i64
Returns the value of total_memory_bytes, or the default value if total_memory_bytes is unset.
Sourcepub fn max_num_of_cpu_cores(&self) -> i32
pub fn max_num_of_cpu_cores(&self) -> i32
Returns the value of max_num_of_cpu_cores, or the default value if max_num_of_cpu_cores is unset.