pub struct FormCheckbox {
pub description: Option<String>,
pub checked: Option<bool>,
pub required: Option<bool>,
pub id: Option<String>,
}Fields
description: Option<String>checked: Option<bool>required: Option<bool>id: Option<String>Implementations
Sourceimpl FormCheckbox
impl FormCheckbox
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.
Sourcepub fn checked(&self) -> bool
pub fn checked(&self) -> bool
Returns the value of checked, or the default value if checked is unset.