pub struct Install {
pub android_id: Option<u64>,
pub version: Option<i32>,
pub bundled: Option<bool>,
pub pending: Option<bool>,
pub last_updated: Option<i64>,
}Fields
android_id: Option<u64>version: Option<i32>bundled: Option<bool>pending: Option<bool>last_updated: Option<i64>Implementations
Sourceimpl Install
impl Install
Sourcepub fn android_id(&self) -> u64
pub fn android_id(&self) -> u64
Returns the value of android_id, or the default value if android_id is unset.
Sourcepub fn version(&self) -> i32
pub fn version(&self) -> i32
Returns the value of version, or the default value if version is unset.
Sourcepub fn bundled(&self) -> bool
pub fn bundled(&self) -> bool
Returns the value of bundled, or the default value if bundled is unset.
Sourcepub fn pending(&self) -> bool
pub fn pending(&self) -> bool
Returns the value of pending, or the default value if pending is unset.
Sourcepub fn last_updated(&self) -> i64
pub fn last_updated(&self) -> i64
Returns the value of last_updated, or the default value if last_updated is unset.