pub struct Offer {Show 29 fields
pub micros: Option<i64>,
pub currency_code: Option<String>,
pub formatted_amount: Option<String>,
pub converted_price: Vec<Offer>,
pub checkout_flow_required: Option<bool>,
pub full_price_micros: Option<i64>,
pub formatted_full_amount: Option<String>,
pub offer_type: Option<i32>,
pub rental_terms: Option<RentalTerms>,
pub on_sale_date: Option<i64>,
pub promotion_label: Vec<String>,
pub subscription_terms: Option<SubscriptionTerms>,
pub formatted_name: Option<String>,
pub formatted_description: Option<String>,
pub preorder: Option<bool>,
pub on_sale_date_display_time_zone_offset_millis: Option<i32>,
pub licensed_offer_type: Option<i32>,
pub subscription_content_terms: Option<SubscriptionContentTerms>,
pub offer_id: Option<String>,
pub preorder_fulfillment_display_date: Option<i64>,
pub license_terms: Option<LicenseTerms>,
pub sale: Option<bool>,
pub voucher_terms: Option<VoucherTerms>,
pub offer_payment: Vec<OfferPayment>,
pub repeat_last_payment: Option<bool>,
pub buy_button_label: Option<String>,
pub instant_purchase_enabled: Option<bool>,
pub sale_end_timestamp: Option<i64>,
pub sale_message: Option<String>,
}Fields
micros: Option<i64>currency_code: Option<String>formatted_amount: Option<String>converted_price: Vec<Offer>checkout_flow_required: Option<bool>full_price_micros: Option<i64>formatted_full_amount: Option<String>offer_type: Option<i32>rental_terms: Option<RentalTerms>on_sale_date: Option<i64>promotion_label: Vec<String>subscription_terms: Option<SubscriptionTerms>formatted_name: Option<String>formatted_description: Option<String>preorder: Option<bool>on_sale_date_display_time_zone_offset_millis: Option<i32>licensed_offer_type: Option<i32>subscription_content_terms: Option<SubscriptionContentTerms>offer_id: Option<String>preorder_fulfillment_display_date: Option<i64>license_terms: Option<LicenseTerms>sale: Option<bool>voucher_terms: Option<VoucherTerms>offer_payment: Vec<OfferPayment>repeat_last_payment: Option<bool>instant_purchase_enabled: Option<bool>sale_end_timestamp: Option<i64>sale_message: Option<String>Implementations
Sourceimpl Offer
impl Offer
Sourcepub fn micros(&self) -> i64
pub fn micros(&self) -> i64
Returns the value of micros, or the default value if micros is unset.
Sourcepub fn currency_code(&self) -> &str
pub fn currency_code(&self) -> &str
Returns the value of currency_code, or the default value if currency_code is unset.
Sourcepub fn formatted_amount(&self) -> &str
pub fn formatted_amount(&self) -> &str
Returns the value of formatted_amount, or the default value if formatted_amount is unset.
Sourcepub fn checkout_flow_required(&self) -> bool
pub fn checkout_flow_required(&self) -> bool
Returns the value of checkout_flow_required, or the default value if checkout_flow_required is unset.
Sourcepub fn full_price_micros(&self) -> i64
pub fn full_price_micros(&self) -> i64
Returns the value of full_price_micros, or the default value if full_price_micros is unset.
Sourcepub fn formatted_full_amount(&self) -> &str
pub fn formatted_full_amount(&self) -> &str
Returns the value of formatted_full_amount, or the default value if formatted_full_amount is unset.
Sourcepub fn offer_type(&self) -> i32
pub fn offer_type(&self) -> i32
Returns the value of offer_type, or the default value if offer_type is unset.
Sourcepub fn on_sale_date(&self) -> i64
pub fn on_sale_date(&self) -> i64
Returns the value of on_sale_date, or the default value if on_sale_date is unset.
Sourcepub fn formatted_name(&self) -> &str
pub fn formatted_name(&self) -> &str
Returns the value of formatted_name, or the default value if formatted_name is unset.
Sourcepub fn formatted_description(&self) -> &str
pub fn formatted_description(&self) -> &str
Returns the value of formatted_description, or the default value if formatted_description is unset.
Sourcepub fn preorder(&self) -> bool
pub fn preorder(&self) -> bool
Returns the value of preorder, or the default value if preorder is unset.
Sourcepub fn on_sale_date_display_time_zone_offset_millis(&self) -> i32
pub fn on_sale_date_display_time_zone_offset_millis(&self) -> i32
Returns the value of on_sale_date_display_time_zone_offset_millis, or the default value if on_sale_date_display_time_zone_offset_millis is unset.
Sourcepub fn licensed_offer_type(&self) -> i32
pub fn licensed_offer_type(&self) -> i32
Returns the value of licensed_offer_type, or the default value if licensed_offer_type is unset.
Sourcepub fn offer_id(&self) -> &str
pub fn offer_id(&self) -> &str
Returns the value of offer_id, or the default value if offer_id is unset.
Sourcepub fn preorder_fulfillment_display_date(&self) -> i64
pub fn preorder_fulfillment_display_date(&self) -> i64
Returns the value of preorder_fulfillment_display_date, or the default value if preorder_fulfillment_display_date is unset.
Sourcepub fn repeat_last_payment(&self) -> bool
pub fn repeat_last_payment(&self) -> bool
Returns the value of repeat_last_payment, or the default value if repeat_last_payment is unset.
Returns the value of buy_button_label, or the default value if buy_button_label is unset.
Sourcepub fn instant_purchase_enabled(&self) -> bool
pub fn instant_purchase_enabled(&self) -> bool
Returns the value of instant_purchase_enabled, or the default value if instant_purchase_enabled is unset.
Sourcepub fn sale_end_timestamp(&self) -> i64
pub fn sale_end_timestamp(&self) -> i64
Returns the value of sale_end_timestamp, or the default value if sale_end_timestamp is unset.
Sourcepub fn sale_message(&self) -> &str
pub fn sale_message(&self) -> &str
Returns the value of sale_message, or the default value if sale_message is unset.