OwnershipInfo

Struct OwnershipInfo 

pub struct OwnershipInfo {
Show 13 fields pub initiation_timestamp: Option<i64>, pub valid_until_timestamp: Option<i64>, pub auto_renewing: Option<bool>, pub refund_timeout_timestamp: Option<i64>, pub post_delivery_refund_window_millis: Option<i64>, pub developer_purchase_info: Option<SignedData>, pub pre_ordered: Option<bool>, pub hidden: Option<bool>, pub rental_terms: Option<RentalTerms>, pub group_license_info: Option<GroupLicenseInfo>, pub licensed_document_info: Option<LicensedDocumentInfo>, pub quantity: Option<i32>, pub library_expiration_timestamp: Option<i64>,
}

Fields

initiation_timestamp: Option<i64>valid_until_timestamp: Option<i64>auto_renewing: Option<bool>refund_timeout_timestamp: Option<i64>post_delivery_refund_window_millis: Option<i64>developer_purchase_info: Option<SignedData>pre_ordered: Option<bool>hidden: Option<bool>rental_terms: Option<RentalTerms>group_license_info: Option<GroupLicenseInfo>licensed_document_info: Option<LicensedDocumentInfo>quantity: Option<i32>library_expiration_timestamp: Option<i64>

Implementations

Source

impl OwnershipInfo

pub fn initiation_timestamp(&self) -> i64

Returns the value of initiation_timestamp, or the default value if initiation_timestamp is unset.

pub fn valid_until_timestamp(&self) -> i64

Returns the value of valid_until_timestamp, or the default value if valid_until_timestamp is unset.

pub fn auto_renewing(&self) -> bool

Returns the value of auto_renewing, or the default value if auto_renewing is unset.

pub fn refund_timeout_timestamp(&self) -> i64

Returns the value of refund_timeout_timestamp, or the default value if refund_timeout_timestamp is unset.

pub fn post_delivery_refund_window_millis(&self) -> i64

Returns the value of post_delivery_refund_window_millis, or the default value if post_delivery_refund_window_millis is unset.

pub fn pre_ordered(&self) -> bool

Returns the value of pre_ordered, or the default value if pre_ordered is unset.

pub fn hidden(&self) -> bool

Returns the value of hidden, or the default value if hidden is unset.

pub fn quantity(&self) -> i32

Returns the value of quantity, or the default value if quantity is unset.

pub fn library_expiration_timestamp(&self) -> i64

Returns the value of library_expiration_timestamp, or the default value if library_expiration_timestamp is unset.