ResolvedLink

Struct ResolvedLink 

pub struct ResolvedLink {
Show 13 fields pub details_url: Option<String>, pub browse_url: Option<String>, pub search_url: Option<String>, pub direct_purchase: Option<DirectPurchase>, pub home_url: Option<String>, pub redeem_gift_card: Option<RedeemGiftCard>, pub server_logs_cookie: Option<Vec<u8>>, pub doc_id: Option<DocId>, pub wishlist_url: Option<String>, pub backend: Option<i32>, pub query: Option<String>, pub my_account_url: Option<String>, pub help_center: Option<HelpCenter>,
}

Fields

details_url: Option<String>browse_url: Option<String>search_url: Option<String>direct_purchase: Option<DirectPurchase>home_url: Option<String>redeem_gift_card: Option<RedeemGiftCard>server_logs_cookie: Option<Vec<u8>>doc_id: Option<DocId>wishlist_url: Option<String>backend: Option<i32>query: Option<String>my_account_url: Option<String>help_center: Option<HelpCenter>

Implementations

pub fn details_url(&self) -> &str

Returns the value of details_url, or the default value if details_url is unset.

pub fn browse_url(&self) -> &str

Returns the value of browse_url, or the default value if browse_url is unset.

pub fn search_url(&self) -> &str

Returns the value of search_url, or the default value if search_url is unset.

pub fn home_url(&self) -> &str

Returns the value of home_url, or the default value if home_url is unset.

Returns the value of server_logs_cookie, or the default value if server_logs_cookie is unset.

pub fn wishlist_url(&self) -> &str

Returns the value of wishlist_url, or the default value if wishlist_url is unset.

pub fn backend(&self) -> i32

Returns the value of backend, or the default value if backend is unset.

pub fn query(&self) -> &str

Returns the value of query, or the default value if query is unset.

pub fn my_account_url(&self) -> &str

Returns the value of my_account_url, or the default value if my_account_url is unset.