pub struct Review {Show 17 fields
pub author_name: Option<String>,
pub url: Option<String>,
pub source: Option<String>,
pub version: Option<String>,
pub timestamp: Option<i64>,
pub star_rating: Option<i32>,
pub title: Option<String>,
pub comment: Option<String>,
pub comment_id: Option<String>,
pub device_name: Option<String>,
pub reply_text: Option<String>,
pub reply_time_stamp: Option<i64>,
pub author: Option<ReviewAuthor>,
pub user_profile: Option<UserProfile>,
pub sentiment: Option<Image>,
pub helpful_count: Option<i32>,
pub thumbs_up_count: Option<i64>,
}Fields
url: Option<String>source: Option<String>version: Option<String>timestamp: Option<i64>star_rating: Option<i32>title: Option<String>comment: Option<String>comment_id: Option<String>device_name: Option<String>reply_text: Option<String>reply_time_stamp: Option<i64>user_profile: Option<UserProfile>sentiment: Option<Image>helpful_count: Option<i32>thumbs_up_count: Option<i64>Implementations
Sourceimpl Review
impl Review
Returns the value of author_name, or the default value if author_name is unset.
Sourcepub fn source(&self) -> &str
pub fn source(&self) -> &str
Returns the value of source, or the default value if source is unset.
Sourcepub fn version(&self) -> &str
pub fn version(&self) -> &str
Returns the value of version, or the default value if version is unset.
Sourcepub fn timestamp(&self) -> i64
pub fn timestamp(&self) -> i64
Returns the value of timestamp, or the default value if timestamp is unset.
Sourcepub fn star_rating(&self) -> i32
pub fn star_rating(&self) -> i32
Returns the value of star_rating, or the default value if star_rating is unset.
Sourcepub fn title(&self) -> &str
pub fn title(&self) -> &str
Returns the value of title, or the default value if title is unset.
Sourcepub fn comment(&self) -> &str
pub fn comment(&self) -> &str
Returns the value of comment, or the default value if comment is unset.
Sourcepub fn comment_id(&self) -> &str
pub fn comment_id(&self) -> &str
Returns the value of comment_id, or the default value if comment_id is unset.
Sourcepub fn device_name(&self) -> &str
pub fn device_name(&self) -> &str
Returns the value of device_name, or the default value if device_name is unset.
Sourcepub fn reply_text(&self) -> &str
pub fn reply_text(&self) -> &str
Returns the value of reply_text, or the default value if reply_text is unset.
Sourcepub fn reply_time_stamp(&self) -> i64
pub fn reply_time_stamp(&self) -> i64
Returns the value of reply_time_stamp, or the default value if reply_time_stamp is unset.
Sourcepub fn helpful_count(&self) -> i32
pub fn helpful_count(&self) -> i32
Returns the value of helpful_count, or the default value if helpful_count is unset.
Sourcepub fn thumbs_up_count(&self) -> i64
pub fn thumbs_up_count(&self) -> i64
Returns the value of thumbs_up_count, or the default value if thumbs_up_count is unset.