pub struct Rule {Show 13 fields
pub negate: Option<bool>,
pub operator: Option<i32>,
pub key: Option<i32>,
pub string_arg: Vec<String>,
pub long_arg: Vec<i64>,
pub double_arg: Vec<f64>,
pub sub_rule: Vec<Rule>,
pub response_code: Option<i32>,
pub comment: Option<String>,
pub string_arg_hash: Vec<u64>,
pub const_arg: Vec<i32>,
pub availability_problem_type: Option<i32>,
pub include_missing_values: Option<bool>,
}Fields
negate: Option<bool>operator: Option<i32>key: Option<i32>string_arg: Vec<String>long_arg: Vec<i64>double_arg: Vec<f64>sub_rule: Vec<Rule>response_code: Option<i32>comment: Option<String>string_arg_hash: Vec<u64>const_arg: Vec<i32>availability_problem_type: Option<i32>include_missing_values: Option<bool>Implementations
Sourceimpl Rule
impl Rule
Sourcepub fn negate(&self) -> bool
pub fn negate(&self) -> bool
Returns the value of negate, or the default value if negate is unset.
Sourcepub fn operator(&self) -> i32
pub fn operator(&self) -> i32
Returns the value of operator, or the default value if operator is unset.
Sourcepub fn response_code(&self) -> i32
pub fn response_code(&self) -> i32
Returns the value of response_code, or the default value if response_code is unset.
Sourcepub fn comment(&self) -> &str
pub fn comment(&self) -> &str
Returns the value of comment, or the default value if comment is unset.
Sourcepub fn availability_problem_type(&self) -> i32
pub fn availability_problem_type(&self) -> i32
Returns the value of availability_problem_type, or the default value if availability_problem_type is unset.
Sourcepub fn include_missing_values(&self) -> bool
pub fn include_missing_values(&self) -> bool
Returns the value of include_missing_values, or the default value if include_missing_values is unset.