pub struct SectionMetaData {
pub header: Option<String>,
pub list_url: Option<String>,
pub browse_url: Option<String>,
pub description: Option<String>,
}Fields
header: Option<String>list_url: Option<String>browse_url: Option<String>description: Option<String>Implementations
Sourceimpl SectionMetaData
impl SectionMetaData
Sourcepub fn header(&self) -> &str
pub fn header(&self) -> &str
Returns the value of header, or the default value if header is unset.
Sourcepub fn list_url(&self) -> &str
pub fn list_url(&self) -> &str
Returns the value of list_url, or the default value if list_url is unset.
Sourcepub fn browse_url(&self) -> &str
pub fn browse_url(&self) -> &str
Returns the value of browse_url, or the default value if browse_url is unset.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.