pub struct TestingProgramDetails {
pub subscribed: Option<bool>,
pub id: Option<i64>,
pub unsubscribed: Option<bool>,
}Fields
subscribed: Option<bool>id: Option<i64>unsubscribed: Option<bool>Implementations
Sourceimpl TestingProgramDetails
impl TestingProgramDetails
Sourcepub fn subscribed(&self) -> bool
pub fn subscribed(&self) -> bool
Returns the value of subscribed, or the default value if subscribed is unset.
Sourcepub fn unsubscribed(&self) -> bool
pub fn unsubscribed(&self) -> bool
Returns the value of unsubscribed, or the default value if unsubscribed is unset.