pub struct AndroidCheckinRequest {Show 22 fields
pub imei: Option<String>,
pub id: Option<i64>,
pub digest: Option<String>,
pub checkin: Option<AndroidCheckinProto>,
pub desired_build: Option<String>,
pub locale: Option<String>,
pub logging_id: Option<i64>,
pub market_checkin: Option<String>,
pub mac_addr: Vec<String>,
pub meid: Option<String>,
pub account_cookie: Vec<String>,
pub time_zone: Option<String>,
pub security_token: Option<u64>,
pub version: Option<i32>,
pub ota_cert: Vec<String>,
pub serial_number: Option<String>,
pub esn: Option<String>,
pub device_configuration: Option<DeviceConfigurationProto>,
pub mac_addr_type: Vec<String>,
pub fragment: Option<i32>,
pub user_name: Option<String>,
pub user_serial_number: Option<i32>,
}Fields
imei: Option<String>id: Option<i64>digest: Option<String>checkin: Option<AndroidCheckinProto>desired_build: Option<String>locale: Option<String>logging_id: Option<i64>market_checkin: Option<String>mac_addr: Vec<String>meid: Option<String>time_zone: Option<String>security_token: Option<u64>version: Option<i32>ota_cert: Vec<String>serial_number: Option<String>esn: Option<String>device_configuration: Option<DeviceConfigurationProto>mac_addr_type: Vec<String>fragment: Option<i32>user_name: Option<String>user_serial_number: Option<i32>Implementations
Sourceimpl AndroidCheckinRequest
impl AndroidCheckinRequest
Sourcepub fn digest(&self) -> &str
pub fn digest(&self) -> &str
Returns the value of digest, or the default value if digest is unset.
Sourcepub fn desired_build(&self) -> &str
pub fn desired_build(&self) -> &str
Returns the value of desired_build, or the default value if desired_build is unset.
Sourcepub fn locale(&self) -> &str
pub fn locale(&self) -> &str
Returns the value of locale, or the default value if locale is unset.
Sourcepub fn logging_id(&self) -> i64
pub fn logging_id(&self) -> i64
Returns the value of logging_id, or the default value if logging_id is unset.
Sourcepub fn market_checkin(&self) -> &str
pub fn market_checkin(&self) -> &str
Returns the value of market_checkin, or the default value if market_checkin is unset.
Sourcepub fn time_zone(&self) -> &str
pub fn time_zone(&self) -> &str
Returns the value of time_zone, or the default value if time_zone is unset.
Sourcepub fn security_token(&self) -> u64
pub fn security_token(&self) -> u64
Returns the value of security_token, or the default value if security_token is unset.
Sourcepub fn version(&self) -> i32
pub fn version(&self) -> i32
Returns the value of version, or the default value if version is unset.
Sourcepub fn serial_number(&self) -> &str
pub fn serial_number(&self) -> &str
Returns the value of serial_number, or the default value if serial_number is unset.
Sourcepub fn fragment(&self) -> i32
pub fn fragment(&self) -> i32
Returns the value of fragment, or the default value if fragment is unset.
Sourcepub fn user_name(&self) -> &str
pub fn user_name(&self) -> &str
Returns the value of user_name, or the default value if user_name is unset.
Sourcepub fn user_serial_number(&self) -> i32
pub fn user_serial_number(&self) -> i32
Returns the value of user_serial_number, or the default value if user_serial_number is unset.