pub struct Item {Show 35 fields
pub id: Option<String>,
pub sub_id: Option<String>,
pub type: Option<i32>,
pub category_id: Option<i32>,
pub title: Option<String>,
pub creator: Option<String>,
pub description_html: Option<String>,
pub offer: Vec<Offer>,
pub availability: Option<Availability>,
pub image: Vec<Image>,
pub sub_item: Vec<Item>,
pub container_metadata: Option<ContainerMetadata>,
pub details: Option<DocumentDetails>,
pub aggregate_rating: Option<AggregateRating>,
pub annotations: Option<Annotations>,
pub details_url: Option<String>,
pub share_url: Option<String>,
pub reviews_url: Option<String>,
pub backend_url: Option<String>,
pub purchase_details_url: Option<String>,
pub details_reusable: Option<bool>,
pub subtitle: Option<String>,
pub translated_description_html: Option<String>,
pub server_logs_cookie: Option<Vec<u8>>,
pub app_info: Option<AppInfo>,
pub mature: Option<bool>,
pub promotional_description: Option<String>,
pub available_for_preregistration: Option<bool>,
pub tip: Vec<ReviewTip>,
pub review_snippets_url: Option<String>,
pub force_shareability: Option<bool>,
pub use_wishlist_as_primary_action: Option<bool>,
pub review_questions_url: Option<String>,
pub review_summary_url: Option<String>,
pub content_rating: Option<ContentRating>,
}Fields
id: Option<String>sub_id: Option<String>type: Option<i32>category_id: Option<i32>title: Option<String>creator: Option<String>description_html: Option<String>offer: Vec<Offer>availability: Option<Availability>image: Vec<Image>sub_item: Vec<Item>container_metadata: Option<ContainerMetadata>details: Option<DocumentDetails>aggregate_rating: Option<AggregateRating>annotations: Option<Annotations>details_url: Option<String>reviews_url: Option<String>backend_url: Option<String>purchase_details_url: Option<String>details_reusable: Option<bool>subtitle: Option<String>translated_description_html: Option<String>app_info: Option<AppInfo>mature: Option<bool>promotional_description: Option<String>available_for_preregistration: Option<bool>tip: Vec<ReviewTip>review_snippets_url: Option<String>use_wishlist_as_primary_action: Option<bool>review_questions_url: Option<String>review_summary_url: Option<String>content_rating: Option<ContentRating>Implementations
Sourceimpl Item
impl Item
Sourcepub fn sub_id(&self) -> &str
pub fn sub_id(&self) -> &str
Returns the value of sub_id, or the default value if sub_id is unset.
Sourcepub fn category_id(&self) -> i32
pub fn category_id(&self) -> i32
Returns the value of category_id, or the default value if category_id is unset.
Sourcepub fn title(&self) -> &str
pub fn title(&self) -> &str
Returns the value of title, or the default value if title is unset.
Sourcepub fn creator(&self) -> &str
pub fn creator(&self) -> &str
Returns the value of creator, or the default value if creator is unset.
Sourcepub fn description_html(&self) -> &str
pub fn description_html(&self) -> &str
Returns the value of description_html, or the default value if description_html is unset.
Sourcepub fn details_url(&self) -> &str
pub fn details_url(&self) -> &str
Returns the value of details_url, or the default value if details_url is unset.
Returns the value of share_url, or the default value if share_url is unset.
Sourcepub fn reviews_url(&self) -> &str
pub fn reviews_url(&self) -> &str
Returns the value of reviews_url, or the default value if reviews_url is unset.
Sourcepub fn backend_url(&self) -> &str
pub fn backend_url(&self) -> &str
Returns the value of backend_url, or the default value if backend_url is unset.
Sourcepub fn purchase_details_url(&self) -> &str
pub fn purchase_details_url(&self) -> &str
Returns the value of purchase_details_url, or the default value if purchase_details_url is unset.
Sourcepub fn details_reusable(&self) -> bool
pub fn details_reusable(&self) -> bool
Returns the value of details_reusable, or the default value if details_reusable is unset.
Sourcepub fn subtitle(&self) -> &str
pub fn subtitle(&self) -> &str
Returns the value of subtitle, or the default value if subtitle is unset.
Sourcepub fn translated_description_html(&self) -> &str
pub fn translated_description_html(&self) -> &str
Returns the value of translated_description_html, or the default value if translated_description_html is unset.
Returns the value of server_logs_cookie, or the default value if server_logs_cookie is unset.
Sourcepub fn mature(&self) -> bool
pub fn mature(&self) -> bool
Returns the value of mature, or the default value if mature is unset.
Sourcepub fn promotional_description(&self) -> &str
pub fn promotional_description(&self) -> &str
Returns the value of promotional_description, or the default value if promotional_description is unset.
Sourcepub fn available_for_preregistration(&self) -> bool
pub fn available_for_preregistration(&self) -> bool
Returns the value of available_for_preregistration, or the default value if available_for_preregistration is unset.
Sourcepub fn review_snippets_url(&self) -> &str
pub fn review_snippets_url(&self) -> &str
Returns the value of review_snippets_url, or the default value if review_snippets_url is unset.
Returns the value of force_shareability, or the default value if force_shareability is unset.
Sourcepub fn use_wishlist_as_primary_action(&self) -> bool
pub fn use_wishlist_as_primary_action(&self) -> bool
Returns the value of use_wishlist_as_primary_action, or the default value if use_wishlist_as_primary_action is unset.
Sourcepub fn review_questions_url(&self) -> &str
pub fn review_questions_url(&self) -> &str
Returns the value of review_questions_url, or the default value if review_questions_url is unset.
Sourcepub fn review_summary_url(&self) -> &str
pub fn review_summary_url(&self) -> &str
Returns the value of review_summary_url, or the default value if review_summary_url is unset.